==> piwigo-2.5.1.zip: piwigo/plugins/LocalFilesEditor/language/pt_BR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['locfiledit_bak_loaded1'] = 'Faça cópia do arquivo baixado.';
$lang['locfiledit_bak_loaded2'] = 'Você deve salvar o arquivo para reustaurá-lo';
$lang['locfiledit_cant_save'] = 'O arquivo atual não tem permissão de escrita. Verifique se o diretório "local/" tem permissão de escrita (chmod).';
$lang['locfiledit_choose_file'] = 'Escolha o arquivo a ser editado.';
$lang['locfiledit_edit'] = 'Edite';
$lang['locfiledit_empty_filename'] = 'Você deve entrar com o nome do arquivo.';
$lang['locfiledit_empty_page'] = 'Página vazia';
$lang['locfiledit_file_already_exists'] = 'O arquivo já existe';
$lang['locfiledit_filename_error'] = 'Caracteres não permitidos no nome do arquivo.';
$lang['locfiledit_model_error'] = 'Você deve escolher um modelo.';
$lang['locfiledit_model'] = 'Modelo';
$lang['locfiledit_new_filename'] = 'Nome do arquivo';
$lang['locfiledit_new_tpl'] = 'Cria novo arquivo';
$lang['locfiledit_newfile'] = 'O arquivo não existe e será criado pelo Editor Local de Arquivos';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_lang'] = 'Idiomas';
$lang['locfiledit_onglet_localconf'] = 'Configuração local';
$lang['locfiledit_onglet_plug'] = 'Plugin Pessoal';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_parent_directory'] = 'Diretório Pai';
$lang['locfiledit_restore_confirm'] = 'Confirma por favor? A restauração não será efetiva até o próximo salvar.';
$lang['locfiledit_restore'] = 'Restaura a cópia de segurança';
$lang['locfiledit_save_bak'] = 'Cópia de segurança será criada ao salvar.';
$lang['locfiledit_save_config'] = 'Arquivo escrito com sucesso.';
$lang['locfiledit_save_file'] = 'Salvar arquivo';
$lang['locfiledit_saved_bak'] = 'Cópia de segurança criada (%s)';
$lang['locfiledit_show_default'] = 'Mostre o arquivo de referência:';
$lang['locfiledit_syntax_error'] = 'Erro de sintaxe! O arquivo não pode ser salvo.';
$lang['locfiledit_webmaster_only'] = 'Somente webmasters podem criar ou modificar arquivos locais.';
?>

==> piwigo-2.5.3.zip: piwigo/plugins/LocalFilesEditor/language/pt_BR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['locfiledit_bak_loaded1'] = 'Faça cópia do arquivo baixado.';
$lang['locfiledit_bak_loaded2'] = 'Você deve salvar o arquivo para restaurá-lo.';
$lang['locfiledit_cant_save'] = 'O arquivo atual não tem permissão de escrita. Verifique se o diretório "local/" tem permissão de escrita (chmod).';
$lang['locfiledit_choose_file'] = 'Escolha o arquivo a ser editado';
$lang['locfiledit_edit'] = 'Edite';
$lang['locfiledit_empty_filename'] = 'Você deve entrar com o nome do arquivo.';
$lang['locfiledit_empty_page'] = 'Página vazia';
$lang['locfiledit_file_already_exists'] = 'O arquivo já existe.';
$lang['locfiledit_filename_error'] = 'Caracteres não permitidos no nome do arquivo.';
$lang['locfiledit_model_error'] = 'Você deve escolher um modelo.';
$lang['locfiledit_model'] = 'Modelo';
$lang['locfiledit_new_filename'] = 'Nome do arquivo';
$lang['locfiledit_new_tpl'] = 'Cria novo arquivo';
$lang['locfiledit_newfile'] = 'O arquivo não existe e será criado pelo Editor Local de Arquivos.';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_lang'] = 'Idiomas';
$lang['locfiledit_onglet_localconf'] = 'Configuração local';
$lang['locfiledit_onglet_plug'] = 'Plugin Pessoal';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_parent_directory'] = 'Pasta pai';
$lang['locfiledit_restore_confirm'] = 'Confirme por favor? A restauração não será efetiva até o próximo salvar.';
$lang['locfiledit_restore'] = 'Restaura a cópia de segurança';
$lang['locfiledit_save_bak'] = 'Cópia de segurança será criada ao salvar.';
$lang['locfiledit_save_config'] = 'Arquivo gravado com sucesso.';
$lang['locfiledit_save_file'] = 'Salvar arquivo';
$lang['locfiledit_saved_bak'] = 'Cópia de segurança criada (%s)';
$lang['locfiledit_show_default'] = 'Mostre o arquivo de referência:';
$lang['locfiledit_syntax_error'] = 'Erro de sintaxe! O arquivo não pode ser salvo.';
$lang['locfiledit_webmaster_only'] = 'Somente webmasters podem criar ou modificar arquivos locais.';
?>
